import time

def main_menu():
    print("\n=== PyPassFusion MENU ===")
    print("[1]. Generate a password")
    print("[2]. Add Your Own password")
    print("[3]. Show generated password")
    print("[4]. Save generated password as a text file")
    print("[5]. Exit")
    print("=================================")

def sub_menu():
    print("\n=== PyPassFusion MENU ===")
    print("[1]. Just want to Save Password?")
    print("[2]. Show user password (not generated one)")
    print("[3]. Save Added password as a text file")
    print("[4]. Back to main menu")
    print("=================================")